#include <WiFi.h>
#include <WiFiClient.h>
#include <WebServer.h>
#include <driver/adc.h>
#include "index_html.h"

WebServer server(80);
float adcval = 0;                    // ADC Mittelwert

void setup(void)
{
  // Initialisiere ESP32 ADC
  adc1_config_width(ADC_WIDTH_12Bit); // ADC Auflösung 10Bit (4096 = 1,1V)
  adc1_config_channel_atten(ADC1_CHANNEL_0, ADC_ATTEN_0db); // Verstärkung 0dB =1,1 V Max

  Serial.begin(115200);
  Serial.print("");
  Serial.println("Start");
  WiFi.mode(WIFI_AP);
  WiFi.softAP("astral", "tiramisu"); // Name und Passwort des Wi-Fi Netzes
  delay(500);
  IPAddress apIP(192, 168, 1, 1);    // Hier wird IP bestimmt
  WiFi.softAPConfig(apIP, apIP, IPAddress(255, 255, 255, 0));
  Serial.println("Starte AP  astral");
  Serial.print("IP Adresse ");       //Ausgabe aktueller IP des Servers
  Serial.println(WiFi.softAPIP());

  server.on("/", Ereignis_Index);
  server.on("/gauge.min.js", Ereignis_js);
  server.on("/ADC.txt", Ereignis_ADC);
  server.onNotFound(handleNotFound);

  server.begin();
  Serial.println("HTTP Server gestarted");
}

void Ereignis_Index()    // Wenn "http://<ip address>/" aufgerufen wurde
{
  server.send(200, "text/html", indexHTML);  //dann Index Webseite senden
}

void Ereignis_js()      // Wenn "http://<ip address>/gauge.min.js" aufgerufen wurde
{
  server.send(200, "text/html", gauge);     // dann gauge.min.js senden 
}

void Ereignis_ADC()     // Wenn "http://<ip address>/ADC.txt" aufgerufen wurde
{
  float temp = (10 * adcval) / 4096; // Maximale Spannung 1,1V erzeugt Wert von 10V
  server.sendHeader("Cache-Control", "no-cache");  // Sehr wichtig !!!!!!!!!!!!!!!!!!!
  server.send(200, "text/plain", String (temp));   // dann text mit ADC Wert senden 
}

void handleNotFound()
{
  server.send(404, "text/plain", "File Not Found\n\n");
}

void loop(void)
{
  server.handleClient();
  // software Tiefpassfilter, filtert Ausreißer
  adcval = ( 15 * adcval + adc1_get_raw ( ADC1_CHANNEL_0 ) ) / 16; // ESP32 ADC 0 Lesen
  delay(10);
}
